#
# spec file for package python-cleo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-cleo
Version:        2.1.0
Release:        1.3
Summary:        Python module for creating testable command-line interfaces
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/sdispater/cleo
Source:         https://github.com/sdispater/cleo/archive/%{version}.tar.gz#/cleo-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module crashtest >= 0.3.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pylev >= 1.3}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rapidfuzz}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-crashtest >= 0.3.1
Requires:       python-pylev >= 1.3
Requires:       python-rapidfuzz >= 2.2.0
BuildArch:      noarch
%python_subpackages

%description
Cleo allows you to create beautiful and testable command-line interfaces.

%prep
%setup -q -n cleo-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/cleo
%{python_sitelib}/cleo-%{version}*info

%changelog
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Added support for Python 3.12 #379
  * Added `CONTRIBUTING.md` document #331
  * Fixed subcommand completions for Fish #359
  * Removed deprecated `-A` option from Fish completions #366
  * Fixed program name discovery in completions script when
    running as module #231
  * Fixed ANSI coloring detection in virtual terminal
    environments (Windows, PyCharm) #104
  * Fixed terminal size detection #299
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.0.1
  - Relax poetry-core requirement for PEP 517 builds (#291).
- 2.0.0 - 2022-11-21
  - No source code changes.
  - This is a version-only release to replace 1.0.0, which was yanked on the
    grounds that it was incompatible with real dependents (i.e. Poetry) based
    on their version specifiers, which explicitly included 1.0.0 pre-releases.
* Sun Oct  9 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.0.0a5
  * no release notes
  * pre-release version required by poetry 1.2
    gh#python-poetry/poetry#3618
* Thu Feb 24 2022 Andreas Schneider <asn@cryptomilk.org>
- Disable python2 which doesn't build
* Mon Oct 26 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.8.1
  * Upgraded clikit to version ^0.6.0
- Kill dephell dependency
* Tue Mar 31 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.0
  * Errors are now rendered in a nicer way for Python 3.6+.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 0.7.6
  * Upgraded `clikit` to fix issues in option parsing.
* Mon Mar 23 2020 Matej Cepl <mcepl@suse.com>
- Add macro %%dephell_genspec to generate setup.py
* Tue Sep 17 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Trim filler wording from
  descriptions.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use the upstream tarball
* Sun Jan 20 2019 Niels Abspoel <aboe76@gmail.com>
- initial packaging
